<?php
/**
 * Registers the block using the metadata loaded from the `block.json` file.
 * Behind the scenes, it registers also all assets so they can be enqueued
 * through the block editor in the corresponding context.
 *
 * @see https://developer.wordpress.org/reference/functions/register_block_type/
 */
function mindd_widget_create_block_dynamic_block_init() {
	load_plugin_textdomain(
		'mindd-widget',
		false,
		dirname( dirname( plugin_basename( __FILE__ ) ) ) . '/languages/'
	);

	register_block_type(
		__DIR__ . '/build',
		array(
			'render_callback' => 'mindd_widget_create_block_dynamic_block_render',
			'attributes'      => array(
				'blockId'  => array(
					'type' => 'string',
				),
				'ApiKey'   => array(
					'type' => 'string',
				),
				'language' => array(
					'type' => 'string',
				),
			),
		)
	);

	wp_set_script_translations( 'mindd-selftriage-widget-editor-script', 'mindd-widget', plugin_dir_path( __FILE__ ) . 'languages' );
}
add_action( 'init', 'mindd_widget_create_block_dynamic_block_init' );

/**
 * Renders the block
 *
 * @param string $attr Block attributes.
 * @param string $content Block content.
 *
 * @return string
 */
function mindd_widget_create_block_dynamic_block_render( $attr, $content ) {
	$options  = get_option( 'mindd_widget' );
	$block_id = $attr['blockId'];
	$api_key  = isset( $attr['ApiKey'] ) ? $attr['ApiKey'] : $options['mindd_widget_api_key'];
	$language = isset( $attr['language'] ) ? $attr['language'] : $options['mindd_widget_default_language_code'];

	ob_start();

	?>
	<div id="mindd_widget_embedded_<?php echo esc_attr( $block_id ); ?>" class="mindd-widget" data-apikey="<?php echo esc_attr( $api_key ); ?>" data-language="<?php echo esc_attr( $language ); ?>"></div>
	<?php

	$widget = ob_get_clean();

	return $widget;
}

?>
