<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @package    Mindd_Widget
 * @subpackage Mindd_Widget/public
 */
class Mindd_Widget_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @var string
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @var string
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @param string $plugin_name Plugin name.
	 * @param string $version Plugin version.
	 */
	public function __construct( $plugin_name, $version ) {
		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @return void
	 */
	public function enqueue_styles() {
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/mindd-widget-public.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @return void
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( $this->plugin_name . '-embed', 'https://moetiknaardedokter.azurewebsites.net/embed/index.js', array(), $this->version, false );

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/mindd-widget-public.js', array( 'jquery' ), $this->version, false );

		$options = get_option( 'mindd_widget' );

		wp_localize_script(
			$this->plugin_name,
			'widget_settings',
			$options
		);
	}

}
